@@ -16,6 +16,7 @@
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
 import os
+import re
 import logging
 from collections import namedtuple
 
@@ -274,7 +275,7 @@ class BootLoaderConfigBase:
         if custom_cmdline:
             cmdline += ' ' + custom_cmdline
         custom_root = self._get_root_cmdline_parameter(uuid)
-        if custom_root:
+        if custom_root and custom_root not in cmdline:
             cmdline += ' ' + custom_root
         return cmdline.strip()
 
@@ -541,37 +542,23 @@ class BootLoaderConfigBase:
         self.proc_mount.bind_mount()
 
     def _get_root_cmdline_parameter(self, uuid):
-        firmware = self.xml_state.build_type.get_firmware()
-        initrd_system = self.xml_state.get_initrd_system()
         cmdline = self.xml_state.build_type.get_kernelcmdline()
         if cmdline and 'root=' in cmdline:
             log.info(
                 'Kernel root device explicitly set via kernelcmdline'
             )
-            return None
+            root_search = re.search(r'(root=(.*)[ ]+|root=(.*)$)', cmdline)
+            if root_search:
+                return root_search.group(1)
 
-        want_root_cmdline_parameter = False
-        if firmware and 'ec2' in firmware:
-            # EC2 requires to specifiy the root device in the bootloader
-            # configuration. This is because the used pvgrub or hvmloader
-            # reads this information and passes it to the guest configuration
-            # which has an impact on the devices attached to the guest.
-            want_root_cmdline_parameter = True
-
-        if initrd_system == 'dracut':
-            # When using a dracut initrd we have to specify the location
-            # of the root device
-            want_root_cmdline_parameter = True
-
-        if want_root_cmdline_parameter:
-            if uuid and self.xml_state.build_type.get_overlayroot():
-                return 'root=overlay:UUID={0}'.format(uuid)
-            elif uuid:
-                return 'root=UUID={0} rw'.format(uuid)
-            else:
-                log.warning(
-                    'root=UUID=<uuid> setup requested, but uuid is not provided'
-                )
+        if uuid and self.xml_state.build_type.get_overlayroot():
+            return 'root=overlay:UUID={0}'.format(uuid)
+        elif uuid:
+            return 'root=UUID={0} rw'.format(uuid)
+        else:
+            log.warning(
+                'root=UUID=<uuid> setup requested, but uuid is not provided'
+            )
 
     def __del__(self):
         log.info('Cleaning up %s instance', type(self).__name__)
