@@ -22,13 +22,21 @@ import platform
 from pkg_resources import resource_filename
 
 # project
-from .path import Path
-from .version import (
+from kiwi.path import Path
+from kiwi.version import (
     __githash__,
     __version__
 )
 
-from .exceptions import KiwiBootLoaderGrubDataError
+from kiwi.exceptions import KiwiBootLoaderGrubDataError
+
+# Default module variables
+POST_DISK_SYNC_SCRIPT = 'disk.sh'
+POST_PREPARE_SCRIPT = 'config.sh'
+PRE_CREATE_SCRIPT = 'images.sh'
+EDIT_BOOT_CONFIG_SCRIPT = 'edit_boot_config.sh'
+EDIT_BOOT_INSTALL_SCRIPT = 'edit_boot_install.sh'
+IMAGE_METADATA_DIR = 'image'
 
 
 class Defaults:
@@ -37,6 +45,7 @@ class Defaults:
 
     Provides static methods for default values and state information
     """
+
     def __init__(self):
         self.defaults = {
             # alignment in bytes
@@ -213,6 +222,17 @@ class Defaults:
             Cli().get_global_args().get('--shared-cache-dir')
         )).lstrip(os.sep)
 
+    @staticmethod
+    def get_sync_options():
+        """
+        Provides list of default data sync options
+
+        :return: list of rsync options
+
+        :rtype: list
+        """
+        return ['-a', '-H', '-X', '-A', '--one-file-system', '--inplace']
+
     @staticmethod
     def get_exclude_list_for_root_data_sync():
         """
@@ -231,6 +251,7 @@ class Defaults:
         ]
         return exclude_list
 
+    @staticmethod
     def get_exclude_list_for_non_physical_devices():
         """
         Provides the list of folders that are not associated
@@ -749,6 +770,8 @@ class Defaults:
         """
         efi_vendor_directories = [
             'EFI/fedora',
+            'EFI/redhat',
+            'EFI/centos',
             'EFI/opensuse'
         ]
         for efi_vendor_directory in efi_vendor_directories:
@@ -780,8 +803,8 @@ class Defaults:
         :rtype: str
         """
         shim_vendor_patterns = [
-            '/boot/efi/EFI/*/shim.efi',
-            '/EFI/*/shim.efi'
+            '/boot/efi/EFI/*/shim*.efi',
+            '/EFI/*/shim*.efi'
         ]
         for shim_vendor_pattern in shim_vendor_patterns:
             for shim_file in glob.iglob(root_path + shim_vendor_pattern):
@@ -1539,6 +1562,7 @@ class Defaults:
         if key in self.defaults:
             return self.defaults[key]
 
+    @staticmethod
     def get_profile_file(root_dir):
         """
         Return name of profile file for given root directory
