@@ -81,7 +81,7 @@ class VolumeManagerLVM(VolumeManagerBase):
                 # the same key to put them on the same level
                 volume_name = 'swap'
             device_map[volume_name] = MappedDevice(
-                device=volume_node, device_provider=self
+                device=volume_node, device_provider=self.device_provider_root
             )
         return device_map
 
@@ -293,10 +293,10 @@ class VolumeManagerLVM(VolumeManagerBase):
             # perform a second lookup of a label specified via the
             # rootfs_label from the type setup
             volume_label = self.custom_args['root_label']
-        filesystem = FileSystem(
+        filesystem = FileSystem.new(
             name=filesystem_name,
             device_provider=MappedDevice(
-                device=device_node, device_provider=self
+                device=device_node, device_provider=self.device_provider_root
             ),
             custom_args=self.custom_filesystem_args
         )
@@ -354,3 +354,5 @@ class VolumeManagerLVM(VolumeManagerBase):
                     log.warning(
                         'volume group %s still busy', self.volume_group
                     )
+                    return
+        self._cleanup_tempdirs()
