@@ -47,7 +47,10 @@ class TestOCIUmoci:
         )
         sync.sync_data.assert_called_once_with(
             exclude=['/dev', '/proc'],
-            options=['-a', '-H', '-X', '-A', '--delete']
+            options=[
+                '-a', '-H', '-X', '-A', '--one-file-system',
+                '--inplace', '--delete'
+            ]
         )
 
     @patch('kiwi.oci_tools.base.DataSync')
@@ -61,7 +64,7 @@ class TestOCIUmoci:
         )
         sync.sync_data.assert_called_once_with(
             exclude=['/dev', '/proc'],
-            options=['-a', '-H', '-X', '-A']
+            options=['-a', '-H', '-X', '-A', '--one-file-system', '--inplace']
         )
 
     @patch('kiwi.oci_tools.umoci.mkdtemp')
